@@ -3,11 +3,10 @@
 # ----------------------------------------------------------
 # @Project: NDN Hydra
 # @Date:    2021-01-25
-# @Author:  Zixuan Zhong
-# @Author:  Justin C Presley
-# @Author:  Daniel Achee
-# @Source-Code: https://github.com/UCLA-IRL/ndn-hydra
-# @Pip-Library: https://pypi.org/project/ndn-hydra/
+# @Authors: Please check AUTHORS.rst
+# @Source-Code:   https://github.com/UCLA-IRL/ndn-hydra
+# @Documentation: https://ndn-hydra.readthedocs.io/
+# @Pip-Library:   https://pypi.org/project/ndn-hydra/
 # ----------------------------------------------------------
 
 import asyncio
@@ -105,7 +104,7 @@ def parse_hydra_cmd_opts() -> Namespace:
 
     # Getting all Arguments
     vars = parser.parse_args()
-
+    logging.basicConfig(level=logging.DEBUG)
     # Configure Arguments
     if vars.function == "insert":
         if not os.path.isfile(vars.path):
