@@ -3,11 +3,10 @@
 # ----------------------------------------------------------
 # @Project: NDN Hydra
 # @Date:    2021-01-25
-# @Author:  Zixuan Zhong
-# @Author:  Justin C Presley
-# @Author:  Daniel Achee
-# @Source-Code: https://github.com/UCLA-IRL/ndn-hydra
-# @Pip-Library: https://pypi.org/project/ndn-hydra/
+# @Authors: Please check AUTHORS.rst
+# @Source-Code:   https://github.com/UCLA-IRL/ndn-hydra
+# @Documentation: https://ndn-hydra.readthedocs.io/
+# @Pip-Library:   https://pypi.org/project/ndn-hydra/
 # ----------------------------------------------------------
 
 import asyncio as aio
@@ -17,7 +16,7 @@ import secrets
 import time
 from ndn.app import NDNApp
 from ndn.encoding import Name, NonStrictName, Component, DecodeError
-from ndn_python_repo import Storage
+from ndn.storage import Storage
 from ndn_hydra.repo.handle_protocol.protocol_handle_base import ProtocolHandle
 from ndn_hydra.repo.protocol.repo_commands import RepoCommand
 from ndn_hydra.repo.utils.pubsub import PubSub
@@ -77,7 +76,6 @@ class InsertCommandHandle(ProtocolHandle):
         # print("receive INSERT command for file: {}".format(Name.to_str(cmd.file.file_name)))
 
         file_name = cmd.file.file_name
-        desired_copies = cmd.file.desired_copies
         packets = cmd.file.packets
         digests = cmd.file.digests
         size = cmd.file.size
@@ -88,13 +86,9 @@ class InsertCommandHandle(ProtocolHandle):
 
         # TODO: check duplicate sequence number
 
-        # are there enough sessions?
-        if desired_copies == 0:
-            self.logger.warning("desired_copies is 0")
-            return
-
         sessions = self.global_view.get_sessions()
 
+        desired_copies = 2
         if len(sessions) < (desired_copies * 2):
             self.logger.warning("not enough node sessions") # TODO: notify the client?
             return
@@ -160,7 +154,7 @@ class InsertCommandHandle(ProtocolHandle):
         add_message.body = add_message_body.encode()
         # apply globalview and send msg thru SVS
         try:
-            next_state_vector = self.main_loop.svs.getCore().getStateTable().getSeqNum(Name.to_str(Name.from_str(self.config['session_id']))) + 1
+            next_state_vector = self.main_loop.svs.getCore().getStateTable().getSeqno(Name.to_str(Name.from_str(self.config['session_id']))) + 1
         except TypeError:
             next_state_vector = 0
         self.global_view.add_insertion(
