@@ -3,17 +3,16 @@
 # ----------------------------------------------------------
 # @Project: NDN Hydra
 # @Date:    2021-01-25
-# @Author:  Zixuan Zhong
-# @Author:  Justin C Presley
-# @Author:  Daniel Achee
-# @Source-Code: https://github.com/UCLA-IRL/ndn-hydra
-# @Pip-Library: https://pypi.org/project/ndn-hydra/
+# @Authors: Please check AUTHORS.rst
+# @Source-Code:   https://github.com/UCLA-IRL/ndn-hydra
+# @Documentation: https://ndn-hydra.readthedocs.io/
+# @Pip-Library:   https://pypi.org/project/ndn-hydra/
 # ----------------------------------------------------------
 
 import logging
 from ndn.app import NDNApp
 from ndn.encoding import Name
-from ndn_python_repo import Storage
+from ndn.storage import Storage
 from ndn_hydra.repo.utils.pubsub import PubSub
 
 class ProtocolHandle(object):
