@@ -3,11 +3,10 @@
 # ----------------------------------------------------------
 # @Project: NDN Hydra
 # @Date:    2021-01-25
-# @Author:  Zixuan Zhong
-# @Author:  Justin C Presley
-# @Author:  Daniel Achee
-# @Source-Code: https://github.com/UCLA-IRL/ndn-hydra
-# @Pip-Library: https://pypi.org/project/ndn-hydra/
+# @Authors: Please check AUTHORS.rst
+# @Source-Code:   https://github.com/UCLA-IRL/ndn-hydra
+# @Documentation: https://ndn-hydra.readthedocs.io/
+# @Pip-Library:   https://pypi.org/project/ndn-hydra/
 # ----------------------------------------------------------
 
 import asyncio as aio
@@ -15,7 +14,7 @@ import logging
 from secrets import choice
 from ndn.app import NDNApp
 from ndn.encoding import Name, ContentType, Component, parse_data
-from ndn_python_repo import Storage
+from ndn.storage import Storage
 from ndn_hydra.repo.global_view.global_view import GlobalView
 
 class ReadHandle(object):
@@ -80,7 +79,7 @@ class ReadHandle(object):
                 self.logger.info(f'[cmd][FETCH] serving data to client')
 
             # serving my own data
-            data_bytes = self.data_storage.get_data_packet(file_name + segment_comp, int_param.can_be_prefix)
+            data_bytes = self.data_storage.get_packet(file_name + segment_comp, int_param.can_be_prefix)
             if data_bytes == None:
                 return
 
@@ -109,6 +108,7 @@ class ReadHandle(object):
             final_id = Component.from_number(int(self.global_view.get_insertion_by_file_name(file_name)["packets"])-1, Component.TYPE_SEGMENT)
             self.app.put_data(int_name, content=link_content, content_type=ContentType.LINK, final_block_id=final_id)
             self.logger.info(f'Read handle: redirected {Name.to_str(int_name)}')
+            self.logger.info(f'Read handle: new name {new_name}')
             return
 
     def _get_file_name_from_interest(self, int_name):
