@@ -3,14 +3,14 @@
 # ----------------------------------------------------------
 # @Project: NDN Hydra
 # @Date:    2021-01-25
-# @Author:  Zixuan Zhong
-# @Author:  Justin C Presley
-# @Author:  Daniel Achee
-# @Source-Code: https://github.com/UCLA-IRL/ndn-hydra
-# @Pip-Library: https://pypi.org/project/ndn-hydra/
+# @Authors: Please check AUTHORS.rst
+# @Source-Code:   https://github.com/UCLA-IRL/ndn-hydra
+# @Documentation: https://ndn-hydra.readthedocs.io/
+# @Pip-Library:   https://pypi.org/project/ndn-hydra/
 # ----------------------------------------------------------
 
 from ndn.encoding import TlvModel, ModelField, NameField, UintField, RepeatedField, BytesField
+from ndn_hydra.repo.repo_messages.add import FileTlv
 
 class RepoTypeNumber:
   REPO_COMMAND = 201
@@ -27,17 +27,16 @@ class RepoTypeNumber:
 class FetchPath(TlvModel):
   prefix = NameField()
 
-class File(TlvModel):
+class CommandFile(TlvModel):
   file_name = NameField()
-  desired_copies = UintField(RepoTypeNumber.DESIRED_COPIES)
   packets = UintField(RepoTypeNumber.PACKETS)
   digests = RepeatedField(BytesField(RepoTypeNumber.DIGEST))
   size = UintField(RepoTypeNumber.SIZE)
 
 class FileList(TlvModel):
-    list = RepeatedField(ModelField(RepoTypeNumber.FILE, File))
+    list = RepeatedField(ModelField(RepoTypeNumber.FILE, FileTlv))
 
 class RepoCommand(TlvModel):
-  file = ModelField(RepoTypeNumber.FILE, File)
+  file = ModelField(RepoTypeNumber.FILE, CommandFile)
   sequence_number = UintField(RepoTypeNumber.SEQUENCE_NUMBER)
   fetch_path = ModelField(RepoTypeNumber.FETCH_PATH, FetchPath)
\ No newline at end of file
